<?php
/**
 * nextus Pro functions and definitions.
 *
 * Sets up the theme and provides some helper functions, which are used
 * in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions file. The child theme's functions file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook.
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * 
 * @subpackage nextuspro
 * @since nextus Pro 1.0
 */
/**
 * Sets up the content width value based on the theme's design and stylesheet.
 */
if (!isset($content_width))
    $content_width = 625;

/**
 * Sets up theme defaults and registers the various WordPress features that
 * nextus Pro supports.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To add a Visual Editor stylesheet.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links,
 * 	custom background, and post formats.
 * @uses register_nav_menu() To add support for navigation menus.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since nextus Pro 1.0
 */
function nextuspro_setup() {
    /*
     * Makes nextus Pro available for translation.
     *
     * Translations can be added to the /languages/ directory.
     * If you're building a theme based on nextus Pro, use a find and replace
     * to change 'nextuspro' to the name of your theme in all the template files.
     */
    load_theme_textdomain('nextuspro', get_template_directory() . '/languages');

    // This theme styles the visual editor with editor-style.css to match the theme style.
    add_editor_style();

    // Adds RSS feed links to <head> for posts and comments.
    add_theme_support('automatic-feed-links');

    // This theme supports a variety of post formats.
    add_theme_support('post-formats', array('aside', 'image', 'link', 'quote', 'status'));

    // This theme uses wp_nav_menu() in one location.
    register_nav_menu('primary', __('Primary Menu', 'nextuspro'));

    /*
     * This theme supports custom background color and image, and here
     * we also set up the default background color.
     */
    add_theme_support('custom-background', array(
        'default-color' => 'e6e6e6',
    ));

    // This theme uses a custom image size for featured images, displayed on "standard" posts.
    add_theme_support('post-thumbnails');
    set_post_thumbnail_size(624, 9999); // Unlimited height, soft crop
}

add_action('after_setup_theme', 'nextuspro_setup');

/**
 * Adds support for a custom header image.
 */
//require( get_template_directory() . '/inc/custom-header.php' );

/**
 * Enqueues scripts and styles for front-end.
 *
 * @since nextus Pro 1.0
 */
function nextuspro_scripts_styles() {
    global $wp_styles;

    /*
     * Adds JavaScript to pages with the comment form to support
     * sites with threaded comments (when in use).
     */
    if (is_singular() && comments_open() && get_option('thread_comments'))
        wp_enqueue_script('comment-reply');

    /*
     * Adds JavaScript for handling the navigation menu hide-and-show behavior.
     */
    wp_enqueue_script('nextuspro-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '1.0', true);

    /*
     * Loads our special font CSS file.
     *
     * The use of Open Sans by default is localized. For languages that use
     * characters not supported by the font, the font can be disabled.
     *
     * To disable in a child theme, use wp_dequeue_style()
     * function mytheme_dequeue_fonts() {
     *     wp_dequeue_style( 'nextuspro-fonts' );
     * }
     * add_action( 'wp_enqueue_scripts', 'mytheme_dequeue_fonts', 11 );
     */

    /* translators: If there are characters in your language that are not supported
      by Open Sans, translate this to 'off'. Do not translate into your own language. */
    if ('off' !== _x('on', 'Open Sans font: on or off', 'nextuspro')) {
        $subsets = 'latin,latin-ext';

        /* translators: To add an additional Open Sans character subset specific to your language, translate
          this to 'greek', 'cyrillic' or 'vietnamese'. Do not translate into your own language. */
        $subset = _x('no-subset', 'Open Sans font: add new subset (greek, cyrillic, vietnamese)', 'nextuspro');

        if ('cyrillic' == $subset)
            $subsets .= ',cyrillic,cyrillic-ext';
        elseif ('greek' == $subset)
            $subsets .= ',greek,greek-ext';
        elseif ('vietnamese' == $subset)
            $subsets .= ',vietnamese';

        $protocol = is_ssl() ? 'https' : 'http';
        $query_args = array(
            'family' => 'Open+Sans:400italic,700italic,400,700',
            'subset' => $subsets,
        );
        wp_enqueue_style('nextuspro-fonts', add_query_arg($query_args, "$protocol://fonts.googleapis.com/css"), array(), null);
    }

    /*
     * Loads our main stylesheet.
     */
    //wp_enqueue_style('nextuspro-style', get_stylesheet_uri());
    wp_enqueue_style('nextuspro-style', get_custom_stylesheet_uri());

    /*
     * Loads the Internet Explorer specific stylesheet.
     */
    wp_enqueue_style('nextuspro-ie', get_template_directory_uri() . '/css/ie.css', array('nextuspro-style'), '20121010');
    $wp_styles->add_data('nextuspro-ie', 'conditional', 'lt IE 9');
}

add_action('wp_enqueue_scripts', 'nextuspro_scripts_styles');

/**
 * Creates a nicely formatted and more specific title element text
 * for output in head of document, based on current view.
 *
 * @since nextus Pro 1.0
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string Filtered title.
 */
function nextuspro_wp_title($title, $sep) {
    global $paged, $page;

    if (is_feed())
        return $title;

    // Add the site name.
    $title .= get_bloginfo('name');

    // Add the site description for the home/front page.
    $site_description = get_bloginfo('description', 'display');
    if ($site_description && ( is_home() || is_front_page() ))
        $title = "$title $sep $site_description";

    // Add a page number if necessary.
    if ($paged >= 2 || $page >= 2)
        $title = "$title $sep " . sprintf(__('Page %s', 'nextuspro'), max($paged, $page));

    return $title;
}

add_filter('wp_title', 'nextuspro_wp_title', 10, 2);

/**
 * Makes our wp_nav_menu() fallback -- wp_page_menu() -- show a home link.
 *
 * @since nextus Pro 1.0
 */
function nextuspro_page_menu_args($args) {
    if (!isset($args['show_home']))
        $args['show_home'] = true;
    return $args;
}

add_filter('wp_page_menu_args', 'nextuspro_page_menu_args');

/**
 * Registers our main widget area and the front page widget areas.
 *
 * @since nextus Pro 1.0
 */
function nextuspro_widgets_init() {
    register_sidebar(array(
        'name' => __('Main Sidebar', 'nextuspro'),
        'id' => 'sidebar-1',
        'description' => __('Appears on posts and pages except the optional Front Page template, which has its own widgets', 'nextuspro'),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));

    register_sidebar(array(
        'name' => __('First Front Page Widget Area', 'nextuspro'),
        'id' => 'sidebar-2',
        'description' => __('Appears when using the optional Front Page template with a page set as Static Front Page', 'nextuspro'),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));

    register_sidebar(array(
        'name' => __('Second Front Page Widget Area', 'nextuspro'),
        'id' => 'sidebar-3',
        'description' => __('Appears when using the optional Front Page template with a page set as Static Front Page', 'nextuspro'),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));
}

add_action('widgets_init', 'nextuspro_widgets_init');

if (!function_exists('nextuspro_content_nav')) :

    /**
     * Displays navigation to next/previous pages when applicable.
     *
     * @since nextus Pro 1.0
     */
    function nextuspro_content_nav($html_id) {
        global $wp_query;

        $html_id = esc_attr($html_id);

        if ($wp_query->max_num_pages > 1) :
            ?>
            <nav id="<?php echo $html_id; ?>" class="navigation" role="navigation">
                <h3 class="assistive-text"><?php _e('Post navigation', 'nextuspro'); ?></h3>
                <div class="nav-previous alignleft"><?php next_posts_link(__('<span class="meta-nav">&larr;</span> Older posts', 'nextuspro')); ?></div>
                <div class="nav-next alignright"><?php previous_posts_link(__('Newer posts <span class="meta-nav">&rarr;</span>', 'nextuspro')); ?></div>
            </nav><!-- #<?php echo $html_id; ?> .navigation -->
            <?php
        endif;
    }

endif;

if (!function_exists('nextuspro_comment')) :

    /**
     * Template for comments and pingbacks.
     *
     * To override this walker in a child theme without modifying the comments template
     * simply create your own nextuspro_comment(), and that function will be used instead.
     *
     * Used as a callback by wp_list_comments() for displaying the comments.
     *
     * @since nextus Pro 1.0
     */
    function nextuspro_comment($comment, $args, $depth) {
        $GLOBALS['comment'] = $comment;
        switch ($comment->comment_type) :
            case 'pingback' :
            case 'trackback' :
                // Display trackbacks differently than normal comments.
                ?>
                <li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
                    <p><?php _e('Pingback:', 'nextuspro'); ?> <?php comment_author_link(); ?> <?php edit_comment_link(__('(Edit)', 'nextuspro'), '<span class="edit-link">', '</span>'); ?></p>
                    <?php
                    break;
                default :
                    // Proceed with normal comments.
                    global $post;
                    ?>
                <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
                    <article id="comment-<?php comment_ID(); ?>" class="comment">
                        <header class="comment-meta comment-author vcard">
                            <?php
                            echo get_avatar($comment, 44);
                            printf('<cite class="fn">%1$s %2$s</cite>', get_comment_author_link(),
                                    // If current post author is also comment author, make it known visually.
                                    ( $comment->user_id === $post->post_author ) ? '<span> ' . __('Post author', 'nextuspro') . '</span>' : ''
                            );
                            printf('<a href="%1$s"><time datetime="%2$s">%3$s</time></a>', esc_url(get_comment_link($comment->comment_ID)), get_comment_time('c'),
                                    /* translators: 1: date, 2: time */ sprintf(__('%1$s at %2$s', 'nextuspro'), get_comment_date(), get_comment_time())
                            );
                            ?>
                        </header><!-- .comment-meta -->

                        <?php if ('0' == $comment->comment_approved) : ?>
                            <p class="comment-awaiting-moderation"><?php _e('Your comment is awaiting moderation.', 'nextuspro'); ?></p>
                        <?php endif; ?>

                        <section class="comment-content comment">
                            <?php comment_text(); ?>
                            <?php edit_comment_link(__('Edit', 'nextuspro'), '<p class="edit-link">', '</p>'); ?>
                        </section><!-- .comment-content -->

                        <div class="reply">
                            <?php comment_reply_link(array_merge($args, array('reply_text' => __('Reply', 'nextuspro'), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
                        </div><!-- .reply -->
                    </article><!-- #comment-## -->
                    <?php
                    break;
            endswitch; // end comment_type check
        }

    endif;

    if (!function_exists('nextuspro_entry_meta')) :

        /**
         * Prints HTML with meta information for current post: categories, tags, permalink, author, and date.
         *
         * Create your own nextuspro_entry_meta() to override in a child theme.
         *
         * @since nextus Pro 1.0
         */
        function nextuspro_entry_meta() {
            // Translators: used between list items, there is a space after the comma.
            $categories_list = get_the_category_list(__(', ', 'nextuspro'));

            // Translators: used between list items, there is a space after the comma.
            $tag_list = get_the_tag_list('', __(', ', 'nextuspro'));

            $date = sprintf('<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a>', esc_url(get_permalink()), esc_attr(get_the_time()), esc_attr(get_the_date('c')), esc_html(get_the_date())
            );

            $author = sprintf('<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>', esc_url(get_author_posts_url(get_the_author_meta('ID'))), esc_attr(sprintf(__('View all posts by %s', 'nextuspro'), get_the_author())), get_the_author()
            );

            // Translators: 1 is category, 2 is tag, 3 is the date and 4 is the author's name.
            if ($tag_list) {
                $utility_text = __('This entry was posted in %1$s and tagged %2$s on %3$s<span class="by-author"> by %4$s</span>.', 'nextuspro');
            } elseif ($categories_list) {
                $utility_text = __('This entry was posted in %1$s on %3$s<span class="by-author"> by %4$s</span>.', 'nextuspro');
            } else {
                $utility_text = __('This entry was posted on %3$s<span class="by-author"> by %4$s</span>.', 'nextuspro');
            }

            printf(
                    $utility_text, $categories_list, $tag_list, $date, $author
            );
        }

    endif;

    /**
     * Extends the default WordPress body class to denote:
     * 1. Using a full-width layout, when no active widgets in the sidebar
     *    or full-width template.
     * 2. Front Page template: thumbnail in use and number of sidebars for
     *    widget areas.
     * 3. White or empty background color to change the layout and spacing.
     * 4. Custom fonts enabled.
     * 5. Single or multiple authors.
     *
     * @since nextus Pro 1.0
     *
     * @param array Existing class values.
     * @return array Filtered class values.
     */
    function nextuspro_body_class($classes) {
        $background_color = get_background_color();

        if (!is_active_sidebar('sidebar-1') || is_page_template('page-templates/full-width.php'))
            $classes[] = 'full-width';

        if (is_page_template('page-templates/front-page.php')) {
            $classes[] = 'template-front-page';
            if (has_post_thumbnail())
                $classes[] = 'has-post-thumbnail';
            if (is_active_sidebar('sidebar-2') && is_active_sidebar('sidebar-3'))
                $classes[] = 'two-sidebars';
        }

        if (empty($background_color))
            $classes[] = 'custom-background-empty';
        elseif (in_array($background_color, array('fff', 'ffffff')))
            $classes[] = 'custom-background-white';

        // Enable custom font class only if the font CSS is queued to load.
        if (wp_style_is('nextuspro-fonts', 'queue'))
            $classes[] = 'custom-font-enabled';

        if (!is_multi_author())
            $classes[] = 'single-author';

        return $classes;
    }

    add_filter('body_class', 'nextuspro_body_class');

    /**
     * Adjusts content_width value for full-width and single image attachment
     * templates, and when there are no active widgets in the sidebar.
     *
     * @since nextus Pro 1.0
     */
    function nextuspro_content_width() {
        if (is_page_template('page-templates/full-width.php') || is_attachment() || !is_active_sidebar('sidebar-1')) {
            global $content_width;
            $content_width = 960;
        }
    }

    add_action('template_redirect', 'nextuspro_content_width');

    /**
     * Add postMessage support for site title and description for the Theme Customizer.
     *
     * @since nextus Pro 1.0
     *
     * @param WP_Customize_Manager $wp_customize Theme Customizer object.
     * @return void
     */
    function nextuspro_customize_register($wp_customize) {
        $wp_customize->get_setting('blogname')->transport = 'postMessage';
        $wp_customize->get_setting('blogdescription')->transport = 'postMessage';
    }

    add_action('customize_register', 'nextuspro_customize_register');

    /**
     * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
     *
     * @since nextus Pro 1.0
     */
    function nextuspro_customize_preview_js() {
        wp_enqueue_script('nextuspro-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array('customize-preview'), '20120827', true);
    }

    add_action('customize_preview_init', 'nextuspro_customize_preview_js');

    function get_custom_stylesheet_uri() {
        if (get_option('np_theme_color') != "") {
            $custom_style = get_option('np_theme_color');
        } else {
            $custom_style = 'style.css';
        }
        $stylesheet_dir_uri = get_stylesheet_directory_uri();
        $stylesheet_uri = $stylesheet_dir_uri . '/css/nextuspro-css/' . $custom_style;
        return apply_filters('stylesheet_uri', $stylesheet_uri, $stylesheet_dir_uri);
    }

    $themename = "Nextus Pro";
    $shortname = "np";
    $url = site_url();
    $categories = get_categories('hide_empty=0&orderby=name');
    $wp_cats = array();
    foreach ($categories as $category_list) {
        $wp_cats[$category_list->cat_ID] = $category_list->cat_name;
    }
    array_unshift($wp_cats, "Choose a category");

    $options = array(
        array("name" => $themename . " Options",
            "type" => "title"),
        array("name" => "Social links",
            "type" => "section"),
        array("type" => "open"),
        array("name" => "Stumble Upon URL",
            "desc" => "Enter the link to your Stumble Upon page",
            "id" => $shortname . "_stumbleupon_link",
            "type" => "text",
            "std" => "http://www.stumbleupon.com/"),
        array("name" => "StumbleUpon Active",
            "desc" => "Check if you want to show Stumble Upon icon",
            "id" => $shortname . "_stumbleupon_active",
            "type" => "checkbox",
            "std" => "true"),
        array("name" => "Twitter URL",
            "desc" => "Enter the twitter to your Twitter page",
            "id" => $shortname . "_twitter_link",
            "type" => "text",
            "std" => "http://twitter.com/"),
        array("name" => "Twitter Active",
            "desc" => "Check if you want to show Twitter icon",
            "id" => $shortname . "_twitter_active",
            "type" => "checkbox",
            "std" => "true"),
        array("name" => "Linkedin URL",
            "desc" => "Enter the link to your Linkedin page",
            "id" => $shortname . "_linkedin_link",
            "type" => "text",
            "std" => "http://linkedin.com/"),
        array("name" => "Linkedin Active",
            "desc" => "Check if you want to show Linkedin icon",
            "id" => $shortname . "_linkedin_active",
            "type" => "checkbox",
            "std" => "true"),
        array("name" => "Technorati URL",
            "desc" => "Enter the link to your Technorati page",
            "id" => $shortname . "_technorati_link",
            "type" => "text",
            "std" => "http://technorati.com/"),
        array("name" => "Technorati Active",
            "desc" => "Check if you want to show Technorati icon",
            "id" => $shortname . "_technorati_active",
            "type" => "checkbox",
            "std" => "true"),
        array("type" => "close"),
        array("name" => "General Settings",
            "type" => "section"),
        array("type" => "open"),
        array("name" => "Theme Option",
            "desc" => "Choose the theme option for specific color",
            "id" => $shortname . "_theme_color",
            "type" => "theme-color",
            "std" => "style.css"),
        array("name" => "Logo image",
            "desc" => "Enter the link to an image size 340px x 90px used for the homepage logo.",
            "id" => $shortname . "_header_img",
            "type" => "file",
            "std" => $url . "/wp-content/themes/nextuspro/images/logo.png"),
        array("name" => "Header Text",
            "desc" => "Enter the Slogan Text",
            "id" => $shortname . "_header_text",
            "type" => "text",
            "std" => "Architecture"),
        array("name" => "Slogan Text",
            "desc" => "Enter the Slogan Text",
            "id" => $shortname . "_slogant_text",
            "type" => "text",
            "std" => "most creative architectural bureau"),
        array("type" => "close"),
        array("name" => "Three Box Panel-1",
            "type" => "section"),
        array("type" => "open"),
        array("name" => "Box-1 Lable",
            "desc" => "Enter the label of Box-1. It can be HTML",
            "id" => $shortname . "_box1_lable",
            "type" => "text",
            "std" => "Welcome!"),
        array("name" => "Box-1 Image",
            "desc" => "Enter the Image Url for Box-1",
            "id" => $shortname . "_box1_image",
            "type" => "file",
            "std" => $url . "/wp-content/themes/nextuspro/images/page1_img1.jpg"),
        array("name" => "Box-1 Link Url",
            "desc" => "Enter the Content for Box-1. It can be HTML",
            "id" => $shortname . "_box1_content_url",
            "type" => "text",
            "std" => "#"),
        array("name" => "Box-1 Content",
            "desc" => "Enter the Content for Box-1. It can be HTML",
            "id" => $shortname . "_box1_content",
            "type" => "textarea",
            "std" => "<b>Our company provides different services from simple planning to the process of building. Welcome to our world where you can find your perfect building.</b>saepe eveniet ut et voluptates estu repudiandae sint et molestiae non recusandaeItaque earum rerum hic"),
        array("name" => "Box-2 Lable",
            "desc" => "Enter the label of Box-2. It can be HTML",
            "id" => $shortname . "_box2_lable",
            "type" => "text",
            "std" => "Solutions Overview"),
        array("name" => "Box-2 Image",
            "desc" => "Enter the Image Url for Box-2",
            "id" => $shortname . "_box2_image",
            "type" => "file",
            "std" => $url . "/wp-content/themes/nextuspro/images/page1_img2.jpg"),
        array("name" => "Box-2 Link Url",
            "desc" => "Enter the Content for Box-2.",
            "id" => $shortname . "_box2_content_url",
            "type" => "text",
            "std" => "#"),
        array("name" => "Box-2 Content",
            "desc" => "Enter the Content for Box-2. It can be HTML",
            "id" => $shortname . "_box2_content",
            "type" => "textarea",
            "std" => "<b>Modern architectural companies offer the wide range of services in the sphere of design and building.</b>Doloresed repeledusempquibusdamet aut rerum odes necessitatibus saepe eveniet ut et voluptates estu repu- diandae sint et molestiae non recusandaeItaque earum"),
        array("name" => "Box-3 Lable",
            "desc" => "Enter the label of Box-3. It can be HTML",
            "id" => $shortname . "_box3_lable",
            "type" => "text",
            "std" => "Latest Projects"),
        array("name" => "Extra-StyleSheet",
            "desc" => "You can paste your  css whech you want to add in content",
            "id" => $shortname . "_three_box_css",
            "type" => "textarea",
            "std" => ""),
//        array("name" => "Box-3 Image",
//            "desc" => "Enter the Image Url for Box-3",
//            "id" => $shortname . "_box3_image",
//            "type" => "text",
//            "std" => $url . "/wp-content/themes/nextuspro/images/box3.png"),
//        array("name" => "Box-3 Link Url",
//            "desc" => "Enter the Content for Box-3.",
//            "id" => $shortname . "_box3_content_url",
//            "type" => "text",
//            "std" => "#"),
//        array("name" => "Box-3 Content",
//            "desc" => "Enter the Content for Box-3. It can be HTML",
//            "id" => $shortname . "_box3_content",
//            "type" => "textarea",
//            "std" => "The company right now has the major market capture to Middle East and Africa and now..."),
        array("type" => "close"),
        array("name" => "Three Box Panel-2",
            "type" => "section"),
        array("type" => "open"),
        array("name" => "Box-1 Lable",
            "desc" => "Enter the label Testimonial. It can be HTML",
            "id" => $shortname . "_two_box1_lable",
            "type" => "text",
            "std" => "Leadership"),
        array("name" => "Box-1 Content",
            "desc" => "Enter the content you want to add. It can be HTML",
            "id" => $shortname . "_two_box1_content",
            "type" => "textarea",
            "std" => "The only leadership that is shown by energy conglomerates is to sustain the corporate structure not our energy needs. The company is fascinated by spotting Leaders who create success by mastering the essence of People Alignment. We Serve the organization by adapting to the host culture establishing a corporate vision and executing..."),
        array("name" => "Two Box-1 Readmore Link Url",
            "desc" => "Enter the Content for Box-1. It can be HTML",
            "id" => $shortname . "_two_box1_content_url",
            "type" => "text",
            "std" => "#"),
        array("name" => "Box-2 Lable",
            "desc" => "Enter the label Testimonial. It can be HTML",
            "id" => $shortname . "_two_box2_lable",
            "type" => "text",
            "std" => "Stratergies"),
        array("name" => "Box-2 Content",
            "desc" => "You can paste your  information which are khown as Testimonial.",
            "id" => $shortname . "_two_box2_content",
            "type" => "textarea",
            "std" => "The company focuses main to improve the factors that affect business growth and engaging people to deliver towards the goals eliminating guesswork. Economies of scale also plays a vital role in the growth strategies of the company. The company also prodigiously focuses to increase in demand for goods and services and exploiting..."),
        array("name" => "Two Box-2 Readmore Link Url",
            "desc" => "Enter the Content for Box-2. It can be HTML",
            "id" => $shortname . "_two_box2_content_url",
            "type" => "text",
            "std" => "#"),
        array("name" => "Box-3 Lable",
            "desc" => "Enter the label Testimonial. It can be HTML",
            "id" => $shortname . "_two_box3_lable",
            "type" => "text",
            "std" => "Testimonials"),
        array("name" => "Box-3 Content",
            "desc" => "You can paste your  information which are khown as Testimonial.",
            "id" => $shortname . "_two_box3_content",
            "type" => "textarea",
            "std" => "Thank you for your assistance with our content for our new website.
Your knowledge in this area, particularly regarding SEO, was invaluable and coupled with your pleasant approach and efficient nature has made the whole experience of dealing with you an absolute pleasure..."),
        array("name" => "Two Box-3 Readmore Link Url",
            "desc" => "Enter the Content for Box-3. It can be HTML",
            "id" => $shortname . "_two_box3_content_url",
            "type" => "text",
            "std" => "#"),
        array("name" => "Extra-StyleSheet",
            "desc" => "You can paste your  css whech you want to add in content",
            "id" => $shortname . "_two_box_css",
            "type" => "textarea",
            "std" => ""),
        array("type" => "close"),
        array("name" => "Footer",
            "type" => "section"),
        array("type" => "open"),
        array("name" => "Reach Us-Lable",
            "desc" => "Enter text used in Reach Us side of the footer. It can be HTML",
            "id" => $shortname . "_footer_reachus_lable",
            "type" => "text",
            "std" => "Reach Us"),
        array("name" => "Reach Us",
            "desc" => "Enter text used in Reach Us side of the footer. It can be HTML",
            "id" => $shortname . "_footer_reachus",
            "type" => "textarea",
            "std" => "+91-079 - 40099900
+91-9898515253
info@architron.com
vipul_architron@yahoo.com"),
        array("name" => "Contact Us-Lable",
            "desc" => "You can paste your contact information which are you want to added to the footer.",
            "id" => $shortname . "_contact_info_lable",
            "type" => "text",
            "std" => "Contact Us"),
        array("name" => "Contact Us",
            "desc" => "You can paste your contact information which are you want to added to the footer.",
            "id" => $shortname . "_contact_info",
            "type" => "textarea",
            "std" => "B-4/4, Sahjanand Complex,
Opp. City Center,
Nr. Sawstik Cross Road,
C. G. Road,
Ahmedabad-380001.
Gujarat (India)"),
        array("name" => "Search-Lable",
            "desc" => "You can write lable for Search which are you want to added to the footer.",
            "id" => $shortname . "_search_lable",
            "type" => "text",
            "std" => "Search Here"),
        array("type" => "close"),
        array("name" => "Sitemap links",
            "type" => "section"),
        array("type" => "open"),
        array("name" => "SiteMape Lable",
            "desc" => "Enter the Lable For your SiteMap",
            "id" => $shortname . "_sitemap1_lable",
            "type" => "text",
            "std" => "Sitemap"),
        array("name" => "Link-1 Lable",
            "desc" => "Enter the Lable For your  page",
            "id" => $shortname . "_sitemap1_link1_lable",
            "type" => "text",
            "std" => "Home"),
        array("name" => "Link-1 Url",
            "desc" => "Enter the url For your  page",
            "id" => $shortname . "_sitemap1_link1_url",
            "type" => "text",
            "std" => "#"),
        array("name" => "Link-2 Lable",
            "desc" => "Enter the Lable For your  page",
            "id" => $shortname . "_sitemap1_link2_lable",
            "type" => "text",
            "std" => "About Us"),
        array("name" => "Link-2 Url",
            "desc" => "Enter the url For your  page",
            "id" => $shortname . "_sitemap1_link2_url",
            "type" => "text",
            "std" => "#"),
        array("name" => "Link-3 Lable",
            "desc" => "Enter the Lable For your  page",
            "id" => $shortname . "_sitemap1_link3_lable",
            "type" => "text",
            "std" => "Services"),
        array("name" => "Link-3 Url",
            "desc" => "Enter the url For your  page",
            "id" => $shortname . "_sitemap1_link3_url",
            "type" => "text",
            "std" => "#"),
        array("name" => "Link-4 Lable",
            "desc" => "Enter the Lable For your  page",
            "id" => $shortname . "_sitemap1_link4_lable",
            "type" => "text",
            "std" => "Clients"),
        array("name" => "Link-4 Url",
            "desc" => "Enter the url For your  page",
            "id" => $shortname . "_sitemap1_link4_url",
            "type" => "text",
            "std" => "#"),
        array("name" => "Link-5 Lable",
            "desc" => "Enter the Lable For your  page",
            "id" => $shortname . "_sitemap1_link5_lable",
            "type" => "text",
            "std" => "Contact Us"),
        array("name" => "Link-5 Url",
            "desc" => "Enter the url For your  page",
            "id" => $shortname . "_sitemap1_link5_url",
            "type" => "text",
            "std" => "#"),
//        array("name" => "SiteMape-2 Lable",
//            "desc" => "Enter the Lable For your SiteMap",
//            "id" => $shortname . "_sitemap2_lable",
//            "type" => "text",
//            "std" => "Studies"),
//        array("name" => "Link-1 Lable",
//            "desc" => "Enter the Lable For your  page",
//            "id" => $shortname . "_sitemap2_link1_lable",
//            "type" => "text",
//            "std" => "Programming"),
//        array("name" => "Link-1 Url",
//            "desc" => "Enter the url For your  page",
//            "id" => $shortname . "_sitemap2_link1_url",
//            "type" => "text",
//            "std" => "#"),
//        array("name" => "Link-2 Lable",
//            "desc" => "Enter the Lable For your  page",
//            "id" => $shortname . "_sitemap2_link2_lable",
//            "type" => "text",
//            "std" => "Facility Assessments"),
//        array("name" => "Link-2 Url",
//            "desc" => "Enter the url For your  page",
//            "id" => $shortname . "_sitemap2_link2_url",
//            "type" => "text",
//            "std" => "#"),
//        array("name" => "Link-3 Lable",
//            "desc" => "Enter the Lable For your  page",
//            "id" => $shortname . "_sitemap2_link3_lable",
//            "type" => "text",
//            "std" => "ADA studies "),
//        array("name" => "Link-3 Url",
//            "desc" => "Enter the url For your  page",
//            "id" => $shortname . "_sitemap2_link3_url",
//            "type" => "text",
//            "std" => "#"),
//        array("name" => "Link-4 Lable",
//            "desc" => "Enter the Lable For your  page",
//            "id" => $shortname . "_sitemap2_link4_lable",
//            "type" => "text",
//            "std" => ""),
//        array("name" => "Link-4 Url",
//            "desc" => "Enter the url For your  page",
//            "id" => $shortname . "_sitemap2_link4_url",
//            "type" => "text",
//            "std" => "#"),
//        
//        array("name" => "SiteMape-3 Lable",
//            "desc" => "Enter the Lable For your SiteMap",
//            "id" => $shortname . "_sitemap3_lable",
//            "type" => "text",
//            "std" => "Graphics"),
//        array("name" => "Link-1 Lable",
//            "desc" => "Enter the Lable For your  page",
//            "id" => $shortname . "_sitemap3_link1_lable",
//            "type" => "text",
//            "std" => "Marketing materials"),
//        array("name" => "Link-1 Url",
//            "desc" => "Enter the url For your  page",
//            "id" => $shortname . "_sitemap3_link1_url",
//            "type" => "text",
//            "std" => "#"),
//        array("name" => "Link-2 Lable",
//            "desc" => "Enter the Lable For your  page",
//            "id" => $shortname . "_sitemap3_link2_lable",
//            "type" => "text",
//            "std" => "Renderings"),
//        array("name" => "Link-2 Url",
//            "desc" => "Enter the url For your  page",
//            "id" => $shortname . "_sitemap3_link2_url",
//            "type" => "text",
//            "std" => "#"),
//        array("name" => "Link-3 Lable",
//            "desc" => "Enter the Lable For your  page",
//            "id" => $shortname . "_sitemap3_link3_lable",
//            "type" => "text",
//            "std" => "Signage"),
//        array("name" => "Link-3 Url",
//            "desc" => "Enter the url For your  page",
//            "id" => $shortname . "_sitemap3_link3_url",
//            "type" => "text",
//            "std" => "#"),
//        array("name" => "Link-4 Lable",
//            "desc" => "Enter the Lable For your  page",
//            "id" => $shortname . "_sitemap3_link4_lable",
//            "type" => "text",
//            "std" => ""),
//        array("name" => "Link-4 Url",
//            "desc" => "Enter the url For your  page",
//            "id" => $shortname . "_sitemap3_link4_url",
//            "type" => "text",
//            "std" => "#"),
        array("type" => "close")
    );
    add_filter('get_search_form', 'new_search_button');

    function new_search_button($text) {
        $text = str_replace('value="Search"', 'value="OK"', $text);
        return $text;
    }

    function mytheme_add_admin() {

        global $themename, $shortname, $options;

        if (isset($_GET['page']) && $_GET['page'] == "functions") {

            if (isset($_REQUEST['action']) && 'save' == $_REQUEST['action']) {

                foreach ($options as $value) {
                    if (isset($value['id']) && isset($_REQUEST[$value['id']])) {
                        update_option($value['id'], $_REQUEST[$value['id']]);
                    }
                }

//                foreach ($options as $value) {
//                    if (isset($_REQUEST[$value['id']])) {
//                        update_option($value['id'], $_REQUEST[$value['id']]);
//                    } else {
//                        if (isset($value['id'])) {
//                            delete_option($value['id']);
//                        }
//                    }
//                }

                redirect("?page=functions&saved=true");
                die;
            } else if (isset($_REQUEST['action']) && 'reset' == $_REQUEST['action']) {

                foreach ($options as $value) {
                    if (isset($value['id'])) {
                        delete_option($value['id']);
                    }
                }

                foreach ($options as $value) {
                    if (isset($value['id'])) {
                        add_option($value['id'], $value['std'], '', 'yes');
                    }
                }

                redirect("?page=functions&reset=true");
                die;
            }
        }

        add_theme_page('Nextus Pro', 'Nextus Pro', 'administrator', "functions", 'mytheme_admin');
        add_theme_page("SliderManager", "Slider Manager", 'administrator', "slide-manager", "slide_manager");
        add_theme_page("ProjectSliderManager", "Project Slider Manager", 'administrator', "project-slider-manager", "project_slider_manager");
    }

    function mytheme_add_init() {

        $file_dir = get_template_directory_uri();
        wp_enqueue_style("functions", $file_dir . "/functions/functions.css", false, "1.0", "all");

        wp_enqueue_script('media-upload');
        wp_enqueue_script('thickbox');
        wp_enqueue_style('thickbox');
        wp_enqueue_style('farbtastic');
        wp_enqueue_script('farbtastic');
        if (isset($_REQUEST['page']) && $_REQUEST['page'] == 'functions'):
            wp_enqueue_script("rm_script", $file_dir . "/functions/rm_script.js", false, "1.0");
        endif;
    }

    function mytheme_admin() {

        global $themename, $shortname, $options;
        $i = 0;

        if (isset($_REQUEST['saved']))
            echo '<div id="message" class="updated fade"><p><strong>' . $themename . ' settings saved.</strong></p></div>';
        if (isset($_REQUEST['reset']))
            echo '<div id="message" class="updated fade"><p><strong>' . $themename . ' settings reset.</strong></p></div>';
        ?>
        <div class="wrap rm_wrap">
            <h2><?php echo $themename; ?> Settings</h2>

            <div class="rm_opts">
                <form method="post">
                    <?php
                    foreach ($options as $value) {
                        switch ($value['type']) {

                            case "open":
                                ?>

                                <?php
                                break;

                            case "close":
                                ?>

                        </div>
                    </div>
                    <br />


                    <?php
                    break;

                case "title":
                    ?>
                    <p>To easily use the <?php echo $themename; ?> theme, you can use the menu below.</p>


                    <?php
                    break;

                case 'text':
                    ?>

                    <div class="rm_input rm_text">
                        <label for="<?php echo $value['id']; ?>"><?php echo $value['name']; ?></label>
                        <input name="<?php echo $value['id']; ?>" id="<?php echo $value['id']; ?>" type="<?php echo $value['type']; ?>" value="<?php
                if (get_option($value['id']) != "") {
                    echo stripslashes(get_option($value['id']));
                } else {
                    echo $value['std'];
                }
                    ?>" />
                        <small><?php echo $value['desc']; ?></small><div class="clearfix"></div>

                    </div>
                    <?php
                    break;

                case 'textarea':
                    ?>

                    <div class="rm_input rm_textarea">
                        <label for="<?php echo $value['id']; ?>"><?php echo $value['name']; ?></label>
                        <textarea name="<?php echo $value['id']; ?>" type="<?php echo $value['type']; ?>" cols="" rows=""><?php
                if (get_option($value['id']) != "") {
                    echo stripslashes(get_option($value['id']));
                } else {
                    echo $value['std'];
                }
                    ?></textarea>
                        <small><?php echo $value['desc']; ?></small><div class="clearfix"></div>

                    </div>

                    <?php
                    break;

                case 'select':
                    ?>

                    <div class="rm_input rm_select">
                        <label for="<?php echo $value['id']; ?>"><?php echo $value['name']; ?></label>

                        <select name="<?php echo $value['id']; ?>" id="<?php echo $value['id']; ?>">
                            <?php foreach ($value['options'] as $option) { ?>
                                <option <?php
                    if (get_option($value['id']) == $option) {
                        echo 'selected="selected"';
                    }
                                ?>><?php echo $option; ?></option><?php } ?>
                        </select>

                        <small><?php echo $value['desc']; ?></small><div class="clearfix"></div>
                    </div>
                    <?php
                    break;

                case "checkbox":
                    ?>

                    <div class="rm_input rm_checkbox">
                        <label for="<?php echo $value['id']; ?>"><?php echo $value['name']; ?></label>

                        <?php
                        if (get_option($value['id'])) {
                            $checked = "checked=\"checked\"";
                        } else {
                            $checked = "";
                        }
                        ?>
                        <input type="checkbox" name="<?php echo $value['id']; ?>" id="<?php echo $value['id']; ?>" value="true" <?php echo $checked; ?> />


                        <small><?php echo $value['desc']; ?></small><div class="clearfix"></div>
                    </div>
                    <?php
                    break;
                case "section":

                    $i++;
                    ?>

                    <div class="rm_section">
                        <div class="rm_title"><h3><img src="<?php echo get_template_directory_uri() ?>/functions/images/trans.png" class="inactive" alt=""><?php echo $value['name']; ?></h3><span class="submit"><input name="save<?php echo $i; ?>" class="submit_btn" type="submit" value="Save changes" />
                            </span><div class="clearfix"></div></div>
                        <div class="rm_options">
                            <?php
                            break;
                        case "file":
                            ?>
                            <div class="rm_input rm_text">
                                <label for="<?php echo $value['id']; ?>"><?php echo $value['name']; ?></label>
                                <input id="<?php echo $value['id']; ?>" type="text" size="36" name="<?php echo $value['id']; ?>" value="<?php
                if (get_option($value['id']) != "") {
                    echo stripslashes(get_option($value['id']));
                } else {
                    echo $value['std'];
                }
                            ?>" /><br/>
                                <input id="upload_image_button_<?php echo $value['id']; ?>" type="button" value="Upload Image" onclick="upload_<?php echo $value['id'] . "()"; ?>" style="margin-left:200px;" />
                                <small><?php echo $value['desc']; ?></small><div class="clearfix"></div>

                            </div>
                            <?php
                            break;
                        case 'color':
                            ?>

                            <div class="rm_input rm_text">
                                <label for="<?php echo $value['id']; ?>"><?php echo $value['name']; ?></label>
                                <input id="<?php echo $value['id']; ?>" name="<?php echo $value['id']; ?>" type="text" value="<?php
                if (get_option($value['id']) != "") {
                    echo stripslashes(get_option($value['id']));
                } else {
                    echo "#";
                }
                            ?>" />
                                <div id="picker_<?php echo $value['id']; ?>" style="float: right;"></div>
                                <div class="clearfix"></div>

                            </div>
                            <?php
                            break;
                        case 'theme-color':
                            ?>
                            <div class="rm_input rm_text">
                                <label for="<?php echo $value['id']; ?>"><?php echo $value['name']; ?></label>

                                <table border="0" width="70%">
                                    <tr>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="style.css" <?php
                if (get_option($value['id']) == 'style.css') {
                    echo "checked";
                }
                            ?> />Black(Default)</td>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="blue.css" <?php
                                   if (get_option($value['id']) == 'blue.css') {
                                       echo "checked";
                                   }
                            ?> />Blue</td>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="brown.css" <?php
                                   if (get_option($value['id']) == 'brown.css') {
                                       echo "checked";
                                   }
                            ?> />Brown</td>
                                        <td rowspan="3"><small style="width: 182px;"><?php echo $value['desc']; ?></small><div class="clearfix"></div></td>
                                    </tr>
                                    <tr>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="dark-cerulean.css" <?php
                                   if (get_option($value['id']) == 'dark-cerulean.css') {
                                       echo "checked";
                                   }
                            ?> />Dark-cerulean</td>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="dark-cyan.css" <?php
                                   if (get_option($value['id']) == 'dark-cyan.css') {
                                       echo "checked";
                                   }
                            ?> />Dark-cyan</td>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="green.css" <?php
                                   if (get_option($value['id']) == 'green.css') {
                                       echo "checked";
                                   }
                            ?> />Green</td>
                                    </tr>
                                    <tr>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="lightgreen.css" <?php
                                   if (get_option($value['id']) == 'lightgreen.css') {
                                       echo "checked";
                                   }
                            ?> />Light-green</td>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="orange.css" <?php
                                   if (get_option($value['id']) == 'orange.css') {
                                       echo "checked";
                                   }
                            ?> />Orange</td>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="pink.css" <?php
                                   if (get_option($value['id']) == 'pink.css') {
                                       echo "checked";
                                   }
                            ?> />Pink</td>
                                    </tr>
                                    <tr>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="purple.css" <?php
                                   if (get_option($value['id']) == 'purple.css') {
                                       echo "checked";
                                   }
                            ?> />Purple</td>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="red.css" <?php
                                   if (get_option($value['id']) == 'red.css') {
                                       echo "checked";
                                   }
                            ?> />Red</td>
                                        <td><input class="radio" type="radio" name="<?php echo $value['id']; ?>" value="yellow.css" <?php
                                   if (get_option($value['id']) == 'yellow.css') {
                                       echo "checked";
                                   }
                            ?> />Yellow</td>
                                    </tr>

                                </table>



                            </div>
                            <?php
                            break;
                    }
                }
                ?>

                <input type="hidden" name="action" value="save" />
                </form>
                <form method="post">
                    <p class="submit">
                        <input name="reset" type="submit" value="Reset" />
                        <input type="hidden" name="action" value="reset" />
                    </p>
                </form>

            </div> 


            <?php
        }

        function generate_tables() {
            global $wpdb, $options;

            $tblQuery = "CREATE TABLE IF NOT EXISTS `" . $wpdb->prefix . "np_images` (
					`image_id` int(11) NOT NULL AUTO_INCREMENT,
					`image_title` varchar(50) NOT NULL,
					`description` varchar(250) NOT NULL,
                                        `image_name` varchar(250) NOT NULL,
					 PRIMARY KEY (`image_id`)
				   )";
            $wpdb->query($tblQuery);
            $tblQuery1 = "CREATE TABLE IF NOT EXISTS `" . $wpdb->prefix . "np_project_images` (
					`image_id` int(11) NOT NULL AUTO_INCREMENT,
					`image_title` varchar(50) NOT NULL,
					`description` varchar(250) NOT NULL,
                                        `image_name` varchar(250) NOT NULL,
					 PRIMARY KEY (`image_id`)
				   )";
            $wpdb->query($tblQuery1);
            $nr = $wpdb->get_results("SELECT * FROM `" . $wpdb->prefix . "np_images`");
            if (isset($_GET['activated']) && count($nr) == '') {
                $tblQuery1 = "INSERT INTO `" . $wpdb->prefix . "np_images` (`image_title`,`description`,`image_name`) VALUES('Slide-1','slider image1','img1.jpg')";
                $wpdb->query($tblQuery1);
                $tblQuery2 = "INSERT INTO  `" . $wpdb->prefix . "np_images` (`image_title`,`description`,`image_name`) VALUES('Slide-2','slider image2','img2.jpg')";
                $wpdb->query($tblQuery2);
                $tblQuery3 = "INSERT INTO  `" . $wpdb->prefix . "np_images` (`image_title`,`description`,`image_name`) VALUES('Slide-2','slider image2','img3.jpg')";
                $wpdb->query($tblQuery3);
                $tblQuery4 = "INSERT INTO  `" . $wpdb->prefix . "np_images` (`image_title`,`description`,`image_name`) VALUES('Slide-2','slider image2','img4.jpg')";
                $wpdb->query($tblQuery4);
            }
            $proimg = $wpdb->get_results("SELECT * FROM `" . $wpdb->prefix . "np_project_images`");
            if (isset($_GET['activated']) && count($proimg) == '') {
                $tblQuery1 = "INSERT INTO `" . $wpdb->prefix . "np_project_images` (`image_title`,`description`,`image_name`) VALUES('Slide-1','slider image1','gallery_img1_active.jpg')";
                $wpdb->query($tblQuery1);
                $tblQuery2 = "INSERT INTO  `" . $wpdb->prefix . "np_project_images` (`image_title`,`description`,`image_name`) VALUES('Slide-2','slider image2','gallery_img2_active.jpg')";
                $wpdb->query($tblQuery2);
                $tblQuery3 = "INSERT INTO  `" . $wpdb->prefix . "np_project_images` (`image_title`,`description`,`image_name`) VALUES('Slide-2','slider image2','gallery_img3_active.jpg')";
                $wpdb->query($tblQuery3);
                $tblQuery4 = "INSERT INTO  `" . $wpdb->prefix . "np_project_images` (`image_title`,`description`,`image_name`) VALUES('Slide-2','slider image2','gallery_img4_active.jpg')";
                $wpdb->query($tblQuery4);
                $tblQuery5 = "INSERT INTO  `" . $wpdb->prefix . "np_project_images` (`image_title`,`description`,`image_name`) VALUES('Slide-2','slider image2','gallery_img5_active.jpg')";
                $wpdb->query($tblQuery5);
                $tblQuery6 = "INSERT INTO  `" . $wpdb->prefix . "np_project_images` (`image_title`,`description`,`image_name`) VALUES('Slide-2','slider image2','gallery_img6_active.jpg')";
                $wpdb->query($tblQuery6);
            }
            if (isset($_GET['activated']) && $_GET['activated'] == "true") {
                foreach ($options as $value) {
                    if (isset($value['id'])) {
                        add_option($value['id'], $value['std'], '', 'yes');
                    }
                }
            }
        }

        function slide_manager() {
            require_once( ABSPATH . 'wp-admin/includes/file.php' );
            global $wpdb;
            $query = "SELECT * FROM `" . $wpdb->prefix . "np_images` ORDER BY `image_id` ASC";
            $images = $wpdb->get_results($query);
            if (isset($_REQUEST['mode'])) {
                $mode = $_REQUEST['mode'];
            }
            if (isset($mode) && $mode == 'addImage') {
                include_once 'functions/addImage.php';
            } elseif (isset($mode) && $mode == 'edit') {
                $query = "SELECT * FROM `" . $wpdb->prefix . "np_images` WHERE `image_id`=" . $_GET['id'] . "";
                $row = $wpdb->get_row($query, ARRAY_A);
                include_once 'functions/addImage.php';
            } elseif (isset($mode) && $mode == 'delete') {
                $query = "DELETE FROM `" . $wpdb->prefix . "np_images` WHERE `image_id`=" . $_GET['id'] . "";
                $row = $wpdb->query($query);
                if ($row) {
                    $message = __('Image has been removed', 'nextuspro');
                } else {
                    $message = __('Image has been removed', 'nextuspro');
                }
                redirect("?page=slide-manager&message=" . urlencode($message));
                exit;
                //header("location:http://localhost/nextuspro/src/wp-admin/admin.php?page=slide-manager&message=". urlencode($message),TRUE);
            } else {

                include_once 'functions/slide_manager.php';
            }
        }

        function project_slider_manager() {
            require_once( ABSPATH . 'wp-admin/includes/file.php' );
            global $wpdb;
            $query = "SELECT * FROM `" . $wpdb->prefix . "np_project_images` ORDER BY `image_id` ASC";
            $images = $wpdb->get_results($query);
            if (isset($_REQUEST['mode'])) {
                $mode = $_REQUEST['mode'];
            }
            if (isset($mode) && $mode == 'p_addImage') {
                include_once 'functions/project_image_add.php';
            } elseif (isset($mode) && $mode == 'edit') {
                $query = "SELECT * FROM `" . $wpdb->prefix . "np_project_images` WHERE `image_id`=" . $_GET['id'] . "";
                $row = $wpdb->get_row($query, ARRAY_A);
                print_r($row);
                include_once 'functions/project_image_add.php';
            } elseif (isset($mode) && $mode == 'delete') {
                $query = "DELETE FROM `" . $wpdb->prefix . "np_project_images` WHERE `image_id`=" . $_GET['id'] . "";
                $row = $wpdb->query($query);
                if ($row) {
                    $message = __('Image has been removed', 'nextuspro');
                } else {
                    $message = __('Image has been removed', 'nextuspro');
                }
                redirect("?page=project-slider-manager&message=" . urlencode($message));
                exit;
                //header("location:http://localhost/nextuspro/src/wp-admin/admin.php?page=slide-manager&message=". urlencode($message),TRUE);
            } else {

                include_once 'functions/project_slider_manager.php';
            }
        }

        function redirect($location = null, $msgtype = null, $message = null) {
            $url = $location;
            if ($msgtype == "message") {
                $url .= '&' . $this->pre . 'updated=true';
            } elseif ($msgtype == "error") {
                $url .= '&' . $this->pre . 'error=true';
            }
            if (!empty($message)) {
                $url .= '&' . $this->pre . 'message=' . urlencode($message);
            }
            ?>
            <script type="text/javascript">
                window.location = '<?php echo (empty($url)) ? home_url() : $url; ?>';
            </script>

            <?php
            flush();
        }

        add_action('admin_init', 'mytheme_add_init');
        add_action('admin_init', 'generate_tables');
// add_action('admin_init', 'nextuspro');
        add_action('admin_menu', 'mytheme_add_admin');
//add_action('admin_head', 'editor_admin_head');
        


